/*
	Author: Aaron Clark - EpochMod.com

    Contributors:

	Description:
	Player Save

    Licence:
    Arma Public License Share Alike (APL-SA) - https://www.bistudio.com/community/licenses/arma-public-license-share-alike

    Github:
    https://github.com/EpochModTeam/Epoch/tree/release/Sources/epoch_server/compile/epoch_player/EPOCH_server_savePlayer.sqf
*/
//[[[cog import generate_private_arrays ]]]
private ["_Svars","_allowSave","_appearance","_bloodPIndex","_bloodPressure","_group","_hitpoints","_loadout","_medical","_playerUID","_pos","_return","_return2","_revive","_schemaVersion","_server_vars","_stats","_vehiclePlyr"];
//[[[end]]]
params [["_player",objNull], ["_vars",[]] ];

if (isNull _player) exitWith {
	diag_log "DEBUG SAVE ABORT null player object";
};

if !(_player getVariable ["SETUP", false]) exitWith {
	diag_log format ["DEBUG SAVE ABORT not setup: %1", _player]
};

_playerUID = _player getVariable ["PUID", ""]; // getPlayerUID _player
if (_playerUID == "") exitWith {
	diag_log format ["DEBUG SAVE ABORT %1", _playerUID]
};

if !(alive _player) exitWith{
	// Dead Stat bit index 0
	_return = ["PlayerStats", _playerUID, 0, 1] call EPOCH_fnc_server_hiveSETBIT;
};

// add vehicle to update queue
_vehiclePlyr = vehicle _player;
if (_vehiclePlyr != _player) then {
	EPOCH_saveVehQueue pushBackUnique  _vehiclePlyr;
};

_allowSave = _vars isEqualTypeParams EPOCH_defaultVars;
if (_allowSave) then{

	if !(_vars isEqualTo EPOCH_defaultVars_SEPXVar) then{
		private _serverOnly = ["Crypto"];
		_Svars = _player getVariable["VARS", call EPOCH_defaultVars_SEPXVar];
		{
			private _cIndex = EPOCH_customVars find _x;
			if (_cIndex != -1) then{
				_vars set[_cIndex, (_Svars select _cIndex)];
			};
		} forEach _serverOnly;
	};
	_player setVariable ["VARS", _vars];

    /* SERVER_VARS INUSE INDEX:
        0 = RESPAWN POS
    */
	_server_vars = _player getVariable["SERVER_VARS", []];

	_group = _player getVariable ["GROUP", ""];
	_revive = _player getVariable ["REVIVE", true];

	_pos = (getposATL _player call EPOCH_precisionPos);

	if (vehicle _player != _player) then {

		private _staticTraderLocationsDistances = [];
		{
			_staticTraderLocationsDistances pushBack [_x distance _player, _x]
		} forEach EPOCH_staticTraderLocations;

		if !(_staticTraderLocationsDistances isEqualTo []) then{
			_staticTraderLocationsDistances sort true;
			_pos = _staticTraderLocationsDistances select 0 select 1;
			_pos set[2, 0];
		};
	};

	// get players hitpoint damage
	_hitpoints = (getAllHitPointsDamage _player) param [2,[]];

	// build medical array
	_medical = [getBleedingRemaining _player, 0, getOxygenRemaining _player, damage _player, _hitpoints];

	// appearance now handled with getUnitLoadout, typeof is still needed to determine players class.
	_appearance = ["", "", "", "", currentWeapon _player, typeOf _player];

	// new save format
	_loadout = getUnitLoadout _player;

	// change this if needed
	_schemaVersion = 1.0;

	// Finally check, if Loadout is a valid Array (will never return an empty Array on units!)
	if !(_loadout isequalto []) then {
		// save player
		_return = ["Player", _playerUID, EPOCH_expiresPlayer, [[getDir _player, _pos, (call EPOCH_fn_InstanceID), _schemaVersion], _medical, _appearance, _server_vars, _vars, _loadout, [], [], [], [], _group, _revive]] call EPOCH_fnc_server_hiveSETEX;
	};
	// save community stats
	_stats = _player getVariable["COMMUNITY_STATS", EPOCH_defaultStatVars];
	_return2 = ["CommunityStats", _playerUID, EPOCH_expiresCommunityStats, [_stats]] call EPOCH_fnc_server_hiveSETEX;

	// blood pressure must stay within 11-179 range
	_bloodPIndex = EPOCH_customVars find "BloodP";
	_bloodPressure = _vars param [_bloodPIndex,100];
	if (_bloodPressure >= 180 || _bloodPressure <= 10) then {
		_player setDamage 1;
		["PlayerStats", _playerUID, 0, 1] call EPOCH_fnc_server_hiveSETBIT;
	} else {
		// set player alive bit
		["PlayerStats", _playerUID, 0, 0] call EPOCH_fnc_server_hiveSETBIT;
	};
};
